Attribute VB_Name = "Program"
' Copyright (c) Traeger Industry Components GmbH.  All Rights Reserved.
Option Explicit

'
' This sample demonstrates how to work with the "PlcAddress" class.
'
Public Sub Main()
    ''' ================================================================================
    ''' The PlcAddress class itself does represent an immutable type which describes the
    ''' metadata stored within a typical compound string value used to access the
    ''' different data areas defined within a PLC device.
    ''' ================================================================================
    
    ' 1. Way: Pure coded ctor use.
    ''' The use of the ctor is most useful in scenarios there the address needs to be
    ''' generated during the runtime of your application/library. So you are not
    ''' forced to generate the compound string value of the address manually.
    
    ' The following example results into the address: 'DB100.DBX 1.0'.
    Dim address1 As PlcAddress
    Set address1 = New_PlcAddress(PlcOperands.DataBlock(100), PlcRawType_Bit, 1, 0)
    
    ' If you want to address a different data area there you do not need to specify
    ' the number of the area like the PERIPHERY INOUT block you just have to change
    ' the operand parameter in the ctor.
    ' The following example results into the address: 'E 1.0'.
    Dim address2 As PlcAddress
    Set address2 = New_PlcAddress(PlcOperands.Input, PlcRawType_Bit, 1, 0)
        
    
    ' 2. Way: Parse existing compound string values to an address.
    ''' The use of the parse methods is useful in scenarios there you may ensure that
    ''' a custom address string is valid and does maybe refer to the
    ''' expected metadata.
    
    ' You can either use the parse method (which throws an exception if the format of
    ' the address string is invalid).
    Dim address11 As PlcAddress
    Set address11 = PlcAddresses.Parse("DB100.DBX 1.0")

    ' Or you use the try parse method (which tries to parse the address string). On
    ' success the resulting address is stored within the out parameter.
    Dim address22 As PlcAddress
    Set address22 = Nothing
    
    Dim success As Boolean
    success = PlcAddresses.TryParse("E 1.0", address22)
    
    
    ''' ================================================================================
    ''' The mechanism used by the PlcAddress class to interpret address strings does
    ''' provide a wide range of flexibility.
    ''' ================================================================================
    
    ' 1. Way: Chaos addresses.
    ''' The following 'chaos' addresses are correctly interpreted by the PlcAddress
    ''' class without to miss any information within the malformed address strings.
        
    ' The following example results into the address: 'DB100.DBX 1.0'.
    Dim address111 As PlcAddress
    Set address111 = PlcAddresses.Parse(" dB 100  . Db 1    . 0  ")
    
    ' The following example results into the address: 'E 1.0'.
    Dim address222 As PlcAddress
    Set address222 = PlcAddresses.Parse(" E x 1  ")
    
    
    ' 2. Way: Siemens and IEC conform address support.
    ''' While Siemens and the IEC do not completly match within the address formats
    ''' specified in their specifications, the use of the PlcAddress does support
    ''' both specifications.
    
    ' You can define an address either in Siemens notation.
    Dim address1111 As PlcAddress
    Set address1111 = PlcAddresses.Parse("E 1.0")
    
    ' Or in IEC notation.
    Dim address2222 As PlcAddress
    Set address2222 = PlcAddresses.Parse("I 1.0")
    
    ''' By default does the PlcAddress class format the address metadata into
    ''' the Siemens format but using additional ToString parameters you can
    ''' specify the desired standard to format the address.
    
    ' The following example results into the address: 'I 1.0'.
    Dim addressStringAsIec As String
    addressStringAsIec = address1111.ToString(PlcOperandStandard_IEC)
    
    ' The following example results into the address: 'E 1.0'.
    Dim addressStringAsSiemens As String
    addressStringAsSiemens = address2222.ToString(PlcOperandStandard_Siemens)
End Sub

